#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 6037 $
$LastChangedDate:: 2022-08-04 13:33:46 +0200#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import numpy as np
from at.lcm.bu21.general.dtypes.unit import UnitConversion


class GeneralGeometryFunctions:

    @staticmethod
    def set_filter(prj, geometry_dict):
        if 'usergroup' in geometry_dict:
            prj['Filter.UserGroup'].setData(geometry_dict['usergroup'])

    @staticmethod
    def set_info(prj, geometry_dict):
        if 'info_name' in geometry_dict:
            prj['Info.Name'].setData(geometry_dict['info_name'])
        else:
            prj['Info.Name'].setData(geometry_dict['component_name'])

        if 'info_functionname' in geometry_dict:
            prj['Info.FunctionName'].setData(geometry_dict['info_functionname'])
        else:
            prj['Info.FunctionName'].setData(geometry_dict['component_name'])

        if 'info_displayname' in geometry_dict:
            prj['Info.DisplayName'].setData(geometry_dict['info_displayname'])
        else:
            prj['Info.DisplayName'].setData(geometry_dict['component_name'].replace('_', ' '))

        if 'webpath' in geometry_dict:
            prj['Info.WebPath'].setData(geometry_dict['webpath'])

    @staticmethod
    def set_dxf(prj, geometry_dict):
        prj['Project.Stator.DRWList.MAG2D'].setData(geometry_dict['dxf_file'])

    @staticmethod
    def set_geometry_properties(prj, geometry_dict):

        # prj['Project.Material.Type'].setData(geometry_dict['class'])
        # prj['Project.Material.Name'].setData(geometry_dict['name'])
        # prj['Project.Material.Manufacturer'].setData(geometry_dict['manufacturer'])
        # GeneralMaterialFunctions.insert_magnet_class(prj, geometry_dict)
        #
        # GeneralMaterialFunctions.insert_value_string(prj, geometry_dict, 'DIN EN', 'Project.Material.DIN-Norm')
        GeneralGeometryFunctions.insert_unit_data(prj, geometry_dict, 'Ns', 'Project.Stator.Ns', "1")
        GeneralGeometryFunctions.insert_unit_data(prj, geometry_dict, 'dsi', 'Project.Stator.dsi', "mm")
        GeneralGeometryFunctions.insert_unit_data(prj, geometry_dict, 'dso', 'Project.Stator.dso', "mm")
        # GeneralMaterialFunctions.insert_unit_data(prj, geometry_dict, 'Density', 'Project.Material.rho', "kg.dm-3")
        # GeneralMaterialFunctions.insert_unit_data(prj, geometry_dict, 'Lamination thickness', 'Project.Material.tlam', "mm")
        #
        # if 'Stacking factor' in geometry_dict and GeneralMaterialFunctions.is_float(geometry_dict['Stacking factor']['value']):
        #     prj['Project.Material.ks'].setData(float(geometry_dict['Stacking factor']['value']))
        # elif 'Lamination thickness' in geometry_dict and GeneralMaterialFunctions.is_float(geometry_dict['Lamination thickness']['value']):
        #     GeneralMaterialFunctions.insert_stacking_factor(prj, geometry_dict, float(geometry_dict['Lamination thickness']['value']), 'Project.Material.ks')
        # else:
        #     prj['Project.Material.ks'].removeParam()
        #     print('Lamination thickness not defined for ' + geometry_dict['component_name'])
        #
        # print('Reference temperature')
        # GeneralMaterialFunctions.insert_unit_data(prj, geometry_dict, 'Reference temperature', 'Project.Material.Theta', "degC", "{:.1f}", 20.0)
        # print('Reference temperature set')
        #
        # prj['Project.Material.colorR'].setData(int(geometry_dict['ColorR']['value']))
        # prj['Project.Material.colorG'].setData(int(geometry_dict['ColorG']['value']))
        # prj['Project.Material.colorB'].setData(int(geometry_dict['ColorB']['value']))
        #
        # GeneralMaterialFunctions.insert_unit_data(prj, geometry_dict, 'Kinematic viscosity', 'Project.Material.nu_visc', "m2.s-1")
        # GeneralMaterialFunctions.insert_unit_data(prj, geometry_dict, 'Dynamic viscosity', 'Project.Material.eta_visc', "Pa.s", "{:.3g}")

    # @staticmethod
    # def insert_data(prj, dict, dict_key, material_parameter, uc):
    #
    #     if dict_key in dict and GeneralMaterialFunctions.is_float(dict[dict_key]):
    #         # prj[material_parameter].setData(float(dict[dict_key]) * conversion_factor)
    #         prj[material_parameter].setData(float("{:.2f}".format(uc.convert(float(dict[dict_key])))))
    #     else:
    #         prj[material_parameter].removeParam()
    #         print(dict_key + ' not defined for ' + dict['component_name'])
    #
    # @staticmethod
    # def insert_data_value(prj, dict, dict_key, material_parameter, uc):
    #
    #     if dict_key in dict and GeneralMaterialFunctions.is_float(dict[dict_key]['value']):
    #         # prj[material_parameter].setData(float(dict[dict_key]['value']) * conversion_factor)
    #         prj[material_parameter].setData(float("{:.2f}".format(uc.convert(float(dict[dict_key]['value'])))))
    #     else:
    #         prj[material_parameter].removeParam()
    #         print(dict_key + ' not defined for ' + dict['component_name'])
    #
    @staticmethod
    def insert_unit_data(prj, dict, dict_key, material_parameter, target_unit, f_digits="{:.2f}", default_value=None):
        print("dict_key: ", dict_key)

        if dict_key in dict and GeneralGeometryFunctions.is_float(dict[dict_key]['value']):
            uc = UnitConversion(dict[dict_key]['unit'].replace('[', '').replace(']', ''), target_unit)
            prj[material_parameter].setData(float(f_digits.format(uc.convert(float(dict[dict_key]['value'])))))
        elif default_value is not None:
            prj[material_parameter].setData(default_value)
            print(material_parameter + 'not defined for ' + dict['component_name'] + ". Set to default = " + str(default_value) + " degC.")
        else:
            prj[material_parameter].removeParam()
            print(dict_key + ' not defined for ' + dict['component_name'])
    #
    # @staticmethod
    # def insert_exact_unit_data(prj, dict, dict_key, material_parameter, target_unit):
    #     print("dict_key: ", dict_key)
    #     if dict_key in dict and GeneralMaterialFunctions.is_float(dict[dict_key]['value']):
    #         uc = UnitConversion(dict[dict_key]['unit'].replace('[', '').replace(']', ''), target_unit)
    #         prj[material_parameter].setData(uc.convert(float(dict[dict_key]['value'])))
    #
    #     else:
    #         prj[material_parameter].removeParam()
    #         print(dict_key + ' not defined for ' + dict['component_name'])
    #
    # @staticmethod
    # def insert_exact_data_value(prj, dict, dict_key, material_parameter, conversion_factor):
    #
    #     if dict_key in dict and GeneralMaterialFunctions.is_float(dict[dict_key]['value']):
    #         # prj[material_parameter].setData(float(dict[dict_key]['value']) * conversion_factor)
    #         prj[material_parameter].setData(float(dict[dict_key]['value']) * conversion_factor)
    #     else:
    #         prj[material_parameter].removeParam()
    #         print(dict_key + ' not defined for ' + dict['component_name'])
    #
    # @staticmethod
    # def insert_value_string(prj, dict, dict_key, material_parameter):
    #
    #     if dict_key in dict and GeneralMaterialFunctions.is_float(dict[dict_key]['value']):
    #         # prj[material_parameter].setData(float(dict[dict_key]['value']) * conversion_factor)
    #         prj[material_parameter].setData(dict[dict_key]['value'])
    #     else:
    #         prj[material_parameter].removeParam()
    #         print(dict_key + ' not defined for ' + dict['component_name'])

    @staticmethod
    def is_float(element):
        return_value = True

        if isinstance(element, list):
            print("Element is a list, not a float")
            return_value = False
        else:
            try:
                float(element)
            except ValueError:
                print("Not a float")
                return_value = False

        return return_value


