#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 5229 $
$LastChangedDate:: 2021-11-16 15:52:35 +0100#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import glob
import json
import os
import shutil
import time

import componentspace.osutils.fileutils as fu
from componentspace.material_component import MaterialComponent
from componentspace.material_utils.material_functions import GeneralMaterialFunctions
from symspace.wrapper.symwrapper import SymProject


class MaterialInsulation(MaterialComponent):
    """

    """

    def createDirectory(self, material):
        """
        Creates a directory with the name of the geometry and the component class
        Copies directories /rst, /help, and /doc

        Parameters
        ----------
        material : dict
           Dictionary of material properties

        """
        # Remove directory

        print("material", material)
        print("Path", self.path)
        print("File", material['component_name'])

        fname = material['component_name']
        path_material = os.path.join(self.path, fname)

        if os.path.exists(path_material):
            shutil.rmtree(path_material, onerror=fu.on_rm_error)
            # wait until OS is finished
            cnt = 0
            while os.path.exists(path_material):
                time.sleep(1)
                cnt = cnt + 1
                if cnt > 3:
                    raise ValueError('Cannot remove path!')

        # Create material directory
        if not os.path.exists(path_material):
            os.mkdir(path_material)

        shutil.copy(os.path.join(self.path, 'InsulationMaterial.mop'),
                    os.path.join(path_material, material['component_name'] + '.mop'))

        # Copy rst
        fu.copyFileAndReplace(os.path.join(self.path, 'index.rst'),
                              os.path.join(path_material, 'index.rst'),
                              [('__ComponentTitle__', material['component_name'] + '\n' + len(material['component_name']) * '='),
                               ('__Comment__', material['comment']),
                               ('__MaterialName__', material['name']),
                               ('__Manufacturer__', material['manufacturer']),
                               ('__PDF__', material['pdf_file'])])

        fu.copyTree(os.path.join(self.path, 'rst'), os.path.join(path_material, 'rst'))

        # Copy pdf file
        pdf_file = os.path.join(self.path, 'resources', material['pdf_file'])
        if os.path.isfile(pdf_file):
            shutil.copy(pdf_file, os.path.join(path_material, 'rst', material['pdf_file']))

        # Modify material file
        prj = SymProject.load(os.path.join(path_material, material['component_name'] + '.mop'))

        GeneralMaterialFunctions.set_filter(prj, material)
        GeneralMaterialFunctions.set_info(prj, material)
        GeneralMaterialFunctions.set_general_properties(prj, material)
        GeneralMaterialFunctions.set_electromagnetic_properties(prj, material)
        GeneralMaterialFunctions.set_mechanic_properties(prj, material)
        GeneralMaterialFunctions.set_thermal_properties(prj, material)

        prj.save()

    def buildComponent(self, keep_mopc: bool = False):
        folder_resources = str(os.path.join(self.path, "resources"))
        # data = {}

        for i, filename in enumerate(glob.glob(folder_resources + "/*.json")):
            print('**** {} ****'.format(filename))

            with open(filename, "r") as json_file:
                data = json.load(json_file)

                self.createDirectory(data)
                # print("component_name: ", mat['component_name'])
                comp = MaterialComponent(os.path.join(self.path, data['component_name'], data['component_name'] + '.mop'))
                comp.base_directory = self.path
                comp.buildComponent()
