#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 7679 $
$LastChangedDate:: 2024-01-30 16:18:29 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import json
import yaml
from symspace.gui.qt.form_dialog import FormDialog


def convert(node: dict) -> dict:
    if 'component' in node:
        component = node.get('component', dict())
    elif 'name' in node:
        component = node
    else:
        return dict()
    wf = dict(__a__name=component.get('name', ''),
              __b__path=component.get('path', ''),
              __c__version=component.get('version', '0.1'),
              __d__ruleGuid=component.get('ruleGuid', ''),
              __e__settings=[])
    children = []
    for child in node.get('children', []):
        children.append(convert(child))
    wf['__f__children'] = children
    return wf


def custom_sort(item):
    # ToDo: This function is currently not in use. YAML should be sorted
    # Define the desired sorting order for the keys
    sort_order = ['name', 'path', 'version', 'settings', 'children']
    key = item[0]
    # Check if the key is present in the sort order
    if key in sort_order:
        return sort_order.index(key)
    else:
        # If the key is not in the sort order, give it a high sort order
        return len(sort_order)


def run_dialog(sym_prj):

    start_path = sym_prj.getDirectory()
    file_type = 'JSON files (*.json)'

    form_title = 'Convert JSON to YAML'
    form_elements = [('Select JSON file', 'browse_file', start_path, file_type)]
    form_result = FormDialog.run(form_title, form_elements)
    if form_result['accept']:
        file = form_result['Select JSON file']
        print(file)
        with open(file) as fh:
            prj = json.load(fh)
        outfile = ''
        if 'simulationGraph' in prj:
            workflow = convert(prj['simulationGraph'])
            # wf_sorted = dict(sorted(workflow.items(), key=custom_sort))

            outfile = file.replace('.json', '.yaml')
            with open(outfile, 'w') as stream:
                yaml.dump(workflow, stream)

        elif 'workflow' in prj:
            workflow = convert(prj['workflow'])
            outfile = file.replace('.json', '.yaml')
            with open(outfile, 'w') as stream:
                yaml.dump(workflow, stream)

        if outfile != '':
            with open(outfile) as fh:
                str = fh.read()
            str = str.replace('__a__', '')
            str = str.replace('__b__', '')
            str = str.replace('__c__', '')
            str = str.replace('__d__', '')
            str = str.replace('__e__', '')
            str = str.replace('__f__', '')

            with open(outfile, 'w') as fh:
                fh.write(str)

    else:
        print('Cancelled by user')


if __name__ == '__main__':
    run_dialog(__project__)
