#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5146 $
$LastChangedDate:: 2021-11-03 08:22:53 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

from symspace.wrapper.symwrapper import *
from symspace.console.script_utils import ScriptUtils
import os

def formatResults(results):
    rstr = 'Name; Type; LC; UC\n'
    for res in results:
        if res.getObjective().name.lower() == 'none':
            objtype = ''
        else:
            objtype = res.getObjective().name
        if np.isnan(res.getLB()):
            lb = ''
        else:
            lb = res.getLB()

        if np.isnan(res.getUB()):
            ub = ''
        else:
            ub = res.getUB()
        rstr += f'"{res.getName().replace(prjname, "")}"; {objtype}; {lb}; {ub}\n'
    return(rstr)


if __name__ == '__main__':
    prj = ScriptUtils.getProject(locals())
    problem = ScriptUtils.getProblem(locals())
    prjname = prj.getName() + '.'
    path = prj.getDirectory()

    vars = problem.getVariables()

    with open(os.path.join(path, 'settings.csv'), 'w') as fh:
        fh.write('Variables\n\n')
        fh.write('Name; LB; Step; UB\n')
        for var in vars:
            fh.write(f'"{var.getName().replace(prjname, "")}"; {var.getLB()}; {var.getStepSize()}; {var.getUB()}\n')

        fh.write('\n\n')
        fh.write('Objectives\n\n')
        fh.write(formatResults(problem.getObjectives()))

        fh.write('\n\n')
        fh.write('Constraints\n\n')
        fh.write(formatResults(problem.getConstraints()))

        fh.write('\n\n')
        fh.write('Results\n\n')
        fh.write(formatResults(problem.getResults()))

        print(f'csv file was stored in {path}')

    print('Script finished!')
